@@ -25,25 +25,24 @@
 #define CFGFILE_H
 /*----------------------------------------------------------------------------*/
 /**
- * @fn  char * check_config_path_file (int *i_err)
+ * @fn  char * cfgfile_get_config_path (int *i_err)
  * @brief  Check if config file and path exists, check read/write permissions. 
  *
  * Checks config path and file existence, creates them if needed. Function
- * returns config file path or null if something is wrong. Function writes
+ * returns config file path or null if something went wrong. Function writes
  * checking/creating status to i_err if process completed succefully or not.
  *
- * @param[out]  i_err  Error output
- * @return      Config file path
+ * @param[out] i_err  Error output
+ * @return     Config file path
  *
- * @fn         int set_config_file_path (char *s_path)
- * @brief      Write config path to string
- * @param[out] s_path   String to write config path
- * @return     Result of operation
+ * @fn         char * cfgfile_get_config_path_exit (void)
+ * @brief      Get config file path or exit app if errors occurred.
+ * @return     Config file path
  */
 /*----------------------------------------------------------------------------*/
-char * check_config_path_file (int *i_err);
+char * cfgfile_get_config_path              (int  *i_err);
 
-int    set_config_file_path   (char *s_path) __attribute__ ((nonnull (1)));
+char * cfgfile_get_config_path_exit         (void);
 /*----------------------------------------------------------------------------*/
 #endif
 
