@@ -25,12 +25,27 @@
 #include "cfgfile.h"
 #include "dialogdata.h"
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  DialogData initialization.
+ *
+ * @param[out]  dd_data  DialogData item
+ * @return      none
+ */
+static void dialogdata_init (DialogData *dd_data);
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Free DialogData object.
+ */
 void
 dialogdata_free (DialogData *dd_data)
 {
+    free (dd_data->s_cfg_file);
     free (dd_data);
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  DialogData initialization.
+ */
 static void
 dialogdata_init (DialogData *dd_data)
 {
@@ -41,14 +56,17 @@ dialogdata_init (DialogData *dd_data)
     dd_data->gw_command     = NULL;
     dd_data->gw_interval    = NULL;
     dd_data->gw_inter_combo = NULL;
-
-    memset (dd_data->s_cfg_file, 0, sizeof (dd_data->s_cfg_file));
+    dd_data->s_cfg_file     = NULL;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief   Create new DialogData object.
+ */
 DialogData *
 dialogdata_new (void)
 {
-    DialogData *dd_data = NULL;
+    DialogData *dd_data = NULL;   /* DialogData item to return */
+    int         i_err   = ERR_OK; /* For error output */
 
     dd_data = malloc (sizeof (DialogData));
 
@@ -58,16 +76,22 @@ dialogdata_new (void)
     }
     dialogdata_init (dd_data);
 
-    if (set_config_file_path (dd_data->s_cfg_file) != ERR_OK) {
+    dd_data->s_cfg_file = cfgfile_get_config_path (&i_err);
+
+    if (i_err != ERR_OK) {
         dialogdata_free (dd_data);
         return NULL;
     }
     return dd_data;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get config file path from DialogData.
+ */
 const char *
 dialogdata_get_cfg_file (const DialogData *dd_data)
 {
     return (const char*) dd_data->s_cfg_file;
 }
 /*----------------------------------------------------------------------------*/
+
