@@ -55,7 +55,7 @@ char * read_file_data      (const char   *s_fname,
 
 char * read_file_data_hash (const char   *s_fname,
                             int          *i_err,
-                            uint32_t     *i_hash)
+                            uint_fast32_t     *i_hash)
                             __attribute__ ((nonnull (1)));
 
 int    save_file_data      (const char   *s_fname,
